@@ -17,6 +17,7 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #ifndef COMMON_CONTROL_H
 #define COMMON_CONTROL_H
 
+#include <kscreen/output.h>
 #include <kscreen/types.h>
 
 #include <QObject>
@@ -96,6 +97,16 @@ public:
     void setReplicationSource(const KScreen::OutputPtr &output, const KScreen::OutputPtr &source);
     void setReplicationSource(const QString &outputId, const QString &outputName, const KScreen::OutputPtr &source);
 
+    uint32_t getOverscan(const KScreen::OutputPtr &output) const;
+    uint32_t getOverscan(const QString &outputId, const QString &outputName) const;
+    void setOverscan(const KScreen::OutputPtr &output, const uint32_t value);
+    void setOverscan(const QString &outputId, const QString &outputName, const uint32_t value);
+
+    KScreen::Output::VrrPolicy getVrrPolicy(const KScreen::OutputPtr &output) const;
+    KScreen::Output::VrrPolicy getVrrPolicy(const QString &outputId, const QString &outputName) const;
+    void setVrrPolicy(const KScreen::OutputPtr &output, const KScreen::Output::VrrPolicy value);
+    void setVrrPolicy(const QString &outputId, const QString &outputName, const KScreen::Output::VrrPolicy value);
+
     QString dirPath() const override;
     QString filePath() const override;
 
@@ -133,6 +144,12 @@ public:
     bool getAutoRotateOnlyInTabletMode() const;
     void setAutoRotateOnlyInTabletMode(bool value);
 
+    uint32_t overscan() const;
+    void setOverscan(uint32_t value);
+
+    KScreen::Output::VrrPolicy vrrPolicy() const;
+    void setVrrPolicy(KScreen::Output::VrrPolicy value);
+
     QString dirPath() const override;
     QString filePath() const override;
 
